arc()

Shape / 2D Primitives

Description

Draws an arc in the display window. Angles are given in radians.

Syntax

void arc(float cx, float cy, float w, float h, float start, float stop) void arc(float cx, float cy, float w, float h, float start, float stop, int mode)

Parameters

NameTypeDescription
cxfloatx-coordinate of the center
cyfloaty-coordinate of the center
wfloatwidth of the arc
hfloatheight of the arc
startfloatangle to start the arc (radians)
stopfloatangle to stop the arc (radians)
modeintOPEN, CHORD, or PIE (optional)

Returns

void

Related

Under the Hood

Implementation in Processing.h / Processing.cpp:

Loading...