bezierTangent()
Shape / CurvesDescription
Calculates the tangent of a point on a bezier curve.
Syntax
float bezierTangent(float a, float b, float c, float d, float t)
Parameters
| Name | Type | Description |
|---|---|---|
| a | float | coordinate of first point |
| b | float | coordinate of first control point |
| c | float | coordinate of second control point |
| d | float | coordinate of second point |
| t | float | value between 0 and 1 |
Returns
floatRelated
Under the Hood
From Processing.h:
return bezierTangent((float)a,(float)b,(float)c,(float)d,(float)t);
float bezierTangent(float a, float b, float c, float d, float t);
Under the Hood
From Processing.cpp:
float PApplet::bezierTangent(float a,float b,float c,float d,float t){float u=1-t;return 3*u*u*(b-a)+6*u*t*(c-b)+3*t*t*(d-c);}