circle()

Shape / 2D Primitives

Description

Draws a circle to the screen. By default, the first two parameters set the location of the center, and the third sets the shape's diameter.

Syntax

void circle(float cx, float cy, float d)

Parameters

NameTypeDescription
cxfloatx-coordinate of the center
cyfloaty-coordinate of the center
dfloatdiameter of the circle

Returns

void

Related

Under the Hood

Implementation in Processing.h / Processing.cpp:

Loading...