focused

Environment

Description

Confirms if the sketch window is focused, meaning it is active and will accept keyboard or mouse input. True when focused.

Syntax

focused

Parameters

None

Returns

bool

Under the Hood

Implementation in Processing.h / Processing.cpp:

Loading...