frameCount
EnvironmentDescription
System variable storing the number of frames displayed since the sketch started.
Syntax
frameCount
Parameters
None
Returns
intRelated
Under the Hood
From Processing.h:
int frameCount = 1;
System variable storing the number of frames displayed since the sketch started.
None
From Processing.h: