mouseDragged()
Input / MouseDescription
Called once every time the mouse moves while a button is held.
Syntax
void mouseDragged()
Parameters
None
Returns
voidRelated
Under the Hood
From Processing.h:
virtual void mouseDragged() {}
Called once every time the mouse moves while a button is held.
None
From Processing.h: