mouseMoved()
Input / MouseDescription
Called every time the mouse moves and no button is pressed.
Syntax
void mouseMoved()
Parameters
None
Returns
voidRelated
Under the Hood
From Processing.h:
virtual void mouseMoved() {}
Called every time the mouse moves and no button is pressed.
None
From Processing.h: