mousePressed
Input / MouseDescription
Variable storing whether any mouse button is currently pressed.
Syntax
mousePressed
Parameters
None
Returns
boolRelated
Under the Hood
Implementation in Processing.h / Processing.cpp:
Loading...
Variable storing whether any mouse button is currently pressed.
None
Implementation in Processing.h / Processing.cpp: