popMatrix()
TransformDescription
Pops the current transformation matrix off the matrix stack.
Syntax
void popMatrix()
Parameters
None
Returns
voidRelated
Under the Hood
Implementation in Processing.h / Processing.cpp:
Loading...
Pops the current transformation matrix off the matrix stack.
None
Implementation in Processing.h / Processing.cpp: