screenX()

Lights Camera / Coordinates

Description

Takes a three-dimensional X, Y, Z position and returns the X value for where it will appear on a 2D screen.

Syntax

float screenX(float x, float y, float z)

Parameters

NameTypeDescription
xfloat3D x-coordinate
yfloat3D y-coordinate
zfloat3D z-coordinate

Returns

float

Related

Under the Hood

Implementation in Processing.h / Processing.cpp:

Loading...