screenY()

Lights Camera / Coordinates

Description

Takes a three-dimensional X, Y, Z position and returns the Y value for where it will appear on a 2D screen.

Syntax

float screenY(float x, float y, float z)

Parameters

NameTypeDescription
xfloat3D x-coordinate
yfloat3D y-coordinate
zfloat3D z-coordinate

Returns

float

Related

Under the Hood

From Processing.h:

float screenY(float x, float y, float z=0);

Under the Hood

From Processing.cpp:

float PApplet::screenY(float x,float y,float z){float ox,oy,oz;projectPoint(x,y,z,ox,oy,oz);return oy;}