arc()
Shape / 2D PrimitivesDescription
Draws an arc in the display window. Angles are given in radians.
Syntax
void arc(float cx, float cy, float w, float h, float start, float stop)
void arc(float cx, float cy, float w, float h, float start, float stop, int mode)
Parameters
| Name | Type | Description |
|---|---|---|
| cx | float | x-coordinate of the center |
| cy | float | y-coordinate of the center |
| w | float | width of the arc |
| h | float | height of the arc |
| start | float | angle to start the arc (radians) |
| stop | float | angle to stop the arc (radians) |
| mode | int | OPEN, CHORD, or PIE (optional) |
Returns
voidRelated
Under the Hood
Implementation in Processing.h / Processing.cpp:
Loading...