blend()

Image / Pixels

Description

Copies a region of pixels from one image into another with full alpha channel blending. Blend modes include BLEND, ADD, SUBTRACT, MULTIPLY, SCREEN, DARKEST, LIGHTEST, DIFFERENCE, EXCLUSION.

Syntax

void blend(int sx, int sy, int sw, int sh, int dx, int dy, int dw, int dh, int mode)

Parameters

NameTypeDescription
sxintx-coordinate of source region
syinty-coordinate of source region
swintsource region width
shintsource region height
dxintx-coordinate of destination
dyinty-coordinate of destination
dwintdestination width
dhintdestination height
modeintblend mode constant

Returns

void

Related

Under the Hood

Implementation in Processing.h / Processing.cpp:

Loading...