blend()
Image / PixelsDescription
Copies a region of pixels from one image into another with full alpha channel blending. Blend modes include BLEND, ADD, SUBTRACT, MULTIPLY, SCREEN, DARKEST, LIGHTEST, DIFFERENCE, EXCLUSION.
Syntax
void blend(int sx, int sy, int sw, int sh, int dx, int dy, int dw, int dh, int mode)
Parameters
| Name | Type | Description |
|---|---|---|
| sx | int | x-coordinate of source region |
| sy | int | y-coordinate of source region |
| sw | int | source region width |
| sh | int | source region height |
| dx | int | x-coordinate of destination |
| dy | int | y-coordinate of destination |
| dw | int | destination width |
| dh | int | destination height |
| mode | int | blend mode constant |
Returns
voidRelated
Under the Hood
Implementation in Processing.h / Processing.cpp:
Loading...