circle()
Shape / 2D PrimitivesDescription
Draws a circle to the screen. By default, the first two parameters set the location of the center, and the third sets the shape's diameter.
Syntax
void circle(float cx, float cy, float d)
Parameters
| Name | Type | Description |
|---|---|---|
| cx | float | x-coordinate of the center |
| cy | float | y-coordinate of the center |
| d | float | diameter of the circle |
Returns
voidRelated
Under the Hood
Implementation in Processing.h / Processing.cpp:
Loading...