copy()

Image / Pixels

Description

Copies a region of the display window to another location on the display window.

Syntax

void copy(int sx, int sy, int sw, int sh, int dx, int dy, int dw, int dh)

Parameters

NameTypeDescription
sxintx-coordinate of source
syinty-coordinate of source
swintsource width
shintsource height
dxintx-coordinate of destination
dyinty-coordinate of destination
dwintdestination width
dhintdestination height

Returns

void

Related

Under the Hood

Implementation in Processing.h / Processing.cpp:

Loading...