copy()
Image / PixelsDescription
Copies a region of the display window to another location on the display window.
Syntax
void copy(int sx, int sy, int sw, int sh, int dx, int dy, int dw, int dh)
Parameters
| Name | Type | Description |
|---|---|---|
| sx | int | x-coordinate of source |
| sy | int | y-coordinate of source |
| sw | int | source width |
| sh | int | source height |
| dx | int | x-coordinate of destination |
| dy | int | y-coordinate of destination |
| dw | int | destination width |
| dh | int | destination height |
Returns
voidRelated
Under the Hood
Implementation in Processing.h / Processing.cpp:
Loading...