ellipse()

Shape / 2D Primitives

Description

Draws an ellipse (oval) to the screen. The first two parameters set the location, and the third and fourth parameters set the width and height.

Syntax

void ellipse(float cx, float cy, float w, float h)

Parameters

NameTypeDescription
cxfloatx-coordinate of the center
cyfloaty-coordinate of the center
wfloatwidth of the ellipse
hfloatheight of the ellipse

Returns

void

Related

Under the Hood

Implementation in Processing.h / Processing.cpp:

Loading...