ellipse()
Shape / 2D PrimitivesDescription
Draws an ellipse (oval) to the screen. The first two parameters set the location, and the third and fourth parameters set the width and height.
Syntax
void ellipse(float cx, float cy, float w, float h)
Parameters
| Name | Type | Description |
|---|---|---|
| cx | float | x-coordinate of the center |
| cy | float | y-coordinate of the center |
| w | float | width of the ellipse |
| h | float | height of the ellipse |
Returns
voidRelated
Under the Hood
Implementation in Processing.h / Processing.cpp:
Loading...