frustum()
Lights Camera / CameraDescription
Sets a perspective matrix as defined by the parameters. An off-axis frustum.
Syntax
void frustum(float left, float right, float bottom, float top, float near, float far)
Parameters
| Name | Type | Description |
|---|---|---|
| left | float | left coordinate of the clipping plane |
| right | float | right coordinate |
| bottom | float | bottom coordinate |
| top | float | top coordinate |
| near | float | near z-plane |
| far | float | far z-plane |
Returns
voidRelated
Under the Hood
Implementation in Processing.h / Processing.cpp:
Loading...