keyTyped()
Input / KeyboardDescription
Called once every time a key is pressed, but action keys such as Ctrl, Shift, and Alt are ignored.
Syntax
void keyTyped()
Parameters
None
Returns
voidRelated
Under the Hood
From Processing.h:
virtual void keyTyped() {}