mask()

Image / Pixels

Description

Applies a mask to a PImage. The mask image is a grayscale image where white pixels are opaque and black pixels are transparent.

Syntax

img.mask(const PImage& m)

Parameters

NameTypeDescription
mPImagegrayscale image to use as mask

Returns

void

Related

Under the Hood

Implementation in Processing.h / Processing.cpp:

Loading...