mask()
Image / PixelsDescription
Applies a mask to a PImage. The mask image is a grayscale image where white pixels are opaque and black pixels are transparent.
Syntax
img.mask(const PImage& m)
Parameters
| Name | Type | Description |
|---|---|---|
| m | PImage | grayscale image to use as mask |
Returns
voidRelated
Under the Hood
Implementation in Processing.h / Processing.cpp:
Loading...