mouseMoved()
Input / MouseDescription
Called every time the mouse moves and no button is pressed.
Syntax
void mouseMoved()
Parameters
None
Returns
voidRelated
Under the Hood
Implementation in Processing.h / Processing.cpp:
Loading...
Called every time the mouse moves and no button is pressed.
None
Implementation in Processing.h / Processing.cpp: