ortho()
Lights Camera / CameraDescription
Sets an orthographic projection, where objects appear flat and no foreshortening occurs.
Syntax
void ortho()
void ortho(float left, float right, float bottom, float top, float near, float far)
Parameters
| Name | Type | Description |
|---|---|---|
| left | float | left clipping plane |
| right | float | right clipping plane |
| bottom | float | bottom clipping plane |
| top | float | top clipping plane |
| near | float | near clipping plane |
| far | float | far clipping plane |
Returns
voidRelated
Under the Hood
Implementation in Processing.h / Processing.cpp:
Loading...