screenY()
Lights Camera / CoordinatesDescription
Takes a three-dimensional X, Y, Z position and returns the Y value for where it will appear on a 2D screen.
Syntax
float screenY(float x, float y, float z)
Parameters
| Name | Type | Description |
|---|---|---|
| x | float | 3D x-coordinate |
| y | float | 3D y-coordinate |
| z | float | 3D z-coordinate |
Returns
floatRelated
Under the Hood
From Processing.h:
float screenY(float x, float y, float z=0);
Under the Hood
From Processing.cpp:
float PApplet::screenY(float x,float y,float z){float ox,oy,oz;projectPoint(x,y,z,ox,oy,oz);return oy;}