spotLight()
Lights Camera / LightsDescription
Adds a spotlight. Creates a cone of light from a specific position pointing in a direction.
Syntax
void spotLight(float r, float g, float b, float x, float y, float z, float nx, float ny, float nz, float angle, float concentration)
Parameters
| Name | Type | Description |
|---|---|---|
| r/g/b | float | color components |
| x/y/z | float | position |
| nx/ny/nz | float | direction |
| angle | float | cone angle in radians |
| concentration | float | exponent determining center bias |
Returns
voidRelated
Under the Hood
Implementation in Processing.h / Processing.cpp:
Loading...