textAscent()
Typography / MetricsDescription
Returns the ascent of the current font at its current size. The ascent is the height of the character above the baseline.
Syntax
float textAscent()
Parameters
None
Returns
floatRelated
Under the Hood
Implementation in Processing.h / Processing.cpp:
Loading...