vertex()

Shape / Vertex

Description

Adds a vertex to a shape defined with beginShape().

Syntax

void vertex(float x, float y) void vertex(float x, float y, float z) void vertex(float x, float y, float u, float v) void vertex(float x, float y, float z, float u, float v)

Parameters

NameTypeDescription
xfloatx-coordinate
yfloaty-coordinate
zfloatz-coordinate (optional, 3D)
ufloathorizontal texture coordinate (optional)
vfloatvertical texture coordinate (optional)

Returns

void

Related

Under the Hood

Implementation in Processing.h / Processing.cpp:

Loading...