vertex()
Shape / VertexDescription
Adds a vertex to a shape defined with beginShape().
Syntax
void vertex(float x, float y)
void vertex(float x, float y, float z)
void vertex(float x, float y, float u, float v)
void vertex(float x, float y, float z, float u, float v)
Parameters
| Name | Type | Description |
|---|---|---|
| x | float | x-coordinate |
| y | float | y-coordinate |
| z | float | z-coordinate (optional, 3D) |
| u | float | horizontal texture coordinate (optional) |
| v | float | vertical texture coordinate (optional) |
Returns
voidRelated
Under the Hood
Implementation in Processing.h / Processing.cpp:
Loading...